SyncEngine

Struct SyncEngine 

pub struct SyncEngine<E: Event, B1: EventStoreBackend<E> = InMemoryBackend<E>, B2: EventStoreBackend<E> = InMemoryBackend<E>, R: ConflictResolver<E> = LastWriteWins> { /* private fields */ }
Available on crate feature cqrs only.
Bidirectional sync engine between two event stores.

Implementations

Source

impl<E: Event> SyncEngine<E, InMemoryBackend<E>, InMemoryBackend<E>, LastWriteWins>

pub fn new( local: EventStore<E>, remote: EventStore<E>, resolver: LastWriteWins, ) -> Self

Create a new sync engine with in-memory stores and LastWriteWins resolver.

Source

impl<E: Event, R: ConflictResolver<E>> SyncEngine<E, InMemoryBackend<E>, InMemoryBackend<E>, R>

pub fn with_resolver( local: EventStore<E>, remote: EventStore<E>, resolver: R, ) -> Self

Create a new sync engine with a custom conflict resolver.

pub async fn sync(&self) -> Result<SyncReport, String>

Sync events between local and remote stores.

Pushes new local events to remote, pulls new remote events to local. When conflicting events are detected (both sides modified the same aggregate), they are passed through the ConflictResolver.

pub async fn resolve_conflicts(&self, local: &[E], remote: &[E]) -> Vec<E>

Resolve conflicting events explicitly.

Call this when you have detected conflicting events (e.g., both local and remote modified the same aggregate). Returns the resolved set.