ConflictResolver

Trait ConflictResolver 

pub trait ConflictResolver<E: Event>: Send + Sync {
    // Required method
    fn resolve<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        local: &'life1 [E],
        remote: &'life2 [E],
    ) -> Pin<Box<dyn Future<Output = Vec<E>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait;
}
Available on crate feature cqrs only.
Trait for resolving conflicts between local and remote events.

Required Methods

fn resolve<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, local: &'life1 [E], remote: &'life2 [E], ) -> Pin<Box<dyn Future<Output = Vec<E>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait,

Given conflicting local and remote events, produce a resolved set.

Implementors