pub struct KeyedRateLimiter<K: Hash + Eq + Clone + Send + Sync + 'static> { /* private fields */ }Available on crate feature
resilience only.Expand description
Per-key rate limiter for limiting different resources independently.
Useful for per-endpoint, per-user, or per-API-key rate limiting.
Implementations
Sourceimpl<K: Hash + Eq + Clone + Send + Sync + 'static> KeyedRateLimiter<K>
impl<K: Hash + Eq + Clone + Send + Sync + 'static> KeyedRateLimiter<K>
Sourcepub fn new(default_rps: u32, default_burst: u32) -> Self
pub fn new(default_rps: u32, default_burst: u32) -> Self
Create a new keyed rate limiter with default limits.
Arguments
default_rps- Default requests per second for new keysdefault_burst- Default burst capacity for new keys
Sourcepub fn remove_limit(&self, key: &K)
pub fn remove_limit(&self, key: &K)
Remove limit for a key (will use default on next access).
Sourcepub fn check(&self, key: &K) -> Result<(), RateLimitError>
pub fn check(&self, key: &K) -> Result<(), RateLimitError>
Check if a request for a key is allowed.
Sourcepub fn get_status(&self, key: &K) -> Option<RateLimiterStatus>
pub fn get_status(&self, key: &K) -> Option<RateLimiterStatus>
Get status for a specific key.
Sourcepub fn get_all_status(&self) -> Vec<(K, RateLimiterStatus)>
pub fn get_all_status(&self) -> Vec<(K, RateLimiterStatus)>
Get all keys with their status.