GrpcProductionAdapter

Struct GrpcProductionAdapter 

pub struct GrpcProductionAdapter { /* private fields */ }
Available on crate feature router-grpc only.
Production gRPC adapter with full protobuf support

Features:

  • Full protobuf encoding/decoding
  • Unary RPCs
  • Server streaming
  • Client streaming
  • Bidirectional streaming
  • gRPC reflection
  • HTTP/2 transport

Implementations

Source

impl GrpcProductionAdapter

pub fn new(service_name: impl Into<String>) -> Self

Create a new production gRPC adapter

pub fn service_name(&self) -> &str

Get the service name

pub fn server_builder() -> Server

Create a gRPC server builder

pub fn status_from_code(code: Code, message: impl Into<String>) -> Status

Convert a gRPC status code to Status

pub fn enable_reflection() -> Builder<'static>

Create a reflection server for gRPC service discovery

This enables clients to discover services and their methods at runtime. Useful for tools like grpcurl, grpcui, and Postman.

Returns the builder that can be used to construct the reflection server.