JSON Schema generation for OpenAPI documentation
This module provides types and traits for generating JSON Schema from Rust types. This is used to automatically document request and response types in OpenAPI specifications.
Traits
- ToJson
Schema - Trait for types that can be converted to JSON Schema