pub struct SyncEngine<E: Event, B1: EventStoreBackend<E> = InMemoryBackend<E>, B2: EventStoreBackend<E> = InMemoryBackend<E>, R: ConflictResolver<E> = LastWriteWins> { /* private fields */ }Available on crate feature
cqrs only.Expand description
Bidirectional sync engine between two event stores.
Implementations
Sourceimpl<E: Event> SyncEngine<E, InMemoryBackend<E>, InMemoryBackend<E>, LastWriteWins>
impl<E: Event> SyncEngine<E, InMemoryBackend<E>, InMemoryBackend<E>, LastWriteWins>
Sourcepub fn new(
local: EventStore<E>,
remote: EventStore<E>,
resolver: LastWriteWins,
) -> Self
pub fn new( local: EventStore<E>, remote: EventStore<E>, resolver: LastWriteWins, ) -> Self
Create a new sync engine with in-memory stores and LastWriteWins resolver.
Sourceimpl<E: Event, R: ConflictResolver<E>> SyncEngine<E, InMemoryBackend<E>, InMemoryBackend<E>, R>
impl<E: Event, R: ConflictResolver<E>> SyncEngine<E, InMemoryBackend<E>, InMemoryBackend<E>, R>
Sourcepub fn with_resolver(
local: EventStore<E>,
remote: EventStore<E>,
resolver: R,
) -> Self
pub fn with_resolver( local: EventStore<E>, remote: EventStore<E>, resolver: R, ) -> Self
Create a new sync engine with a custom conflict resolver.
Sourcepub async fn sync(&self) -> Result<SyncReport, String>
pub async fn sync(&self) -> Result<SyncReport, String>
Sync events between local and remote stores.
Pushes new local events to remote, pulls new remote events to local.
When conflicting events are detected (both sides modified the same
aggregate), they are passed through the ConflictResolver.
Sourcepub async fn resolve_conflicts(&self, local: &[E], remote: &[E]) -> Vec<E>
pub async fn resolve_conflicts(&self, local: &[E], remote: &[E]) -> Vec<E>
Resolve conflicting events explicitly.
Call this when you have detected conflicting events (e.g., both local and remote modified the same aggregate). Returns the resolved set.