Handler trait and implementations for protocol-agnostic request handling
Structs
- Handler
Fn - Wrapper for function-based handlers with no arguments
- Handler
With Args - Wrapper for handlers that accept typed, deserialized arguments
- Handler
With State - Wrapper for handlers that receive injected state and typed args
- Handler
With State Only - Wrapper for handlers that receive only injected state (no args)
- Json
- Wrapper that auto-serializes
T: Serializeto JSON. - State
- Newtype wrapper for injected state
Traits
- Handler
- Handler trait for protocol-agnostic request handling
- Into
Handler Result - Trait for converting handler return values into
Result<String, String>.