Module handler

Module handler 

Handler trait and implementations for protocol-agnostic request handling

Structs

HandlerFn
Wrapper for function-based handlers with no arguments
HandlerWithArgs
Wrapper for handlers that accept typed, deserialized arguments
HandlerWithState
Wrapper for handlers that receive injected state and typed args
HandlerWithStateOnly
Wrapper for handlers that receive only injected state (no args)
State
Newtype wrapper for injected state

Traits

Handler
Handler trait for protocol-agnostic request handling